@@ -4,7 +4,7 @@ package Tree::Binary;
 use strict;
 use warnings;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use Scalar::Util qw(blessed);
 
@@ -388,58 +388,108 @@ Tree::Binary - An Object Oriented Binary Tree for Perl
 
 =head1 SYNOPSIS
 
-  use Tree::Binary;
+This program ships as scripts/traverse.1.pl:
 
-  # a tree representaion of the expression:
-  # 	((2 + 2) * (4 + 5))
-  my $btree = Tree::Binary->new("*")
-                          ->setLeft(
-                              Tree::Binary->new("+")
-                                          ->setLeft(Tree::Binary->new("2"))
-                                          ->setRight(Tree::Binary->new("2"))
-                          )
-                          ->setRight(
-                              Tree::Binary->new("+")
-                                          ->setLeft(Tree::Binary->new("4"))
-                                          ->setRight(Tree::Binary->new("5"))
-                          );
-  # Or shown visually:
-  #     +---(*)---+
-  #     |         |
-  #  +-(+)-+   +-(+)-+
-  #  |     |   |     |
-  # (2)   (2) (4)   (5)
+	#!/usr/bin/env perl
 
-  # get a InOrder visitor
-  my $visitor = Tree::Binary::Visitor::InOrderTraversal->new();
-  $btree->accept($visitor);
+	use strict;
+	use warnings;
 
-  # print the expression in infix order
-  print $visitor->getAccumulation(); # prints "2 + 2 * 4 + 5"
+	use Tree::Binary;
+	use Tree::Binary::Visitor::BreadthFirstTraversal;
+	use Tree::Binary::Visitor::InOrderTraversal;
+	use Tree::Binary::Visitor::PreOrderTraversal;
+	use Tree::Binary::Visitor::PostOrderTraversal;
 
-  # get a PreOrder visitor
-  my $visitor = Tree::Binary::Visitor::PreOrderTraversal->new();
-  $btree->accept($visitor);
+	# ---------------
 
-  # print the expression in prefix order
-  print $visitor->getAccumulation(); # prints "* + 2 2 + 4 5"
+	# A tree representaion of the expression:
+	#     ( (2 + 2) * (4 + 5) )
 
-  # get a PostOrder visitor
-  my $visitor = Tree::Binary::Visitor::PostOrderTraversal->new();
-  $btree->accept($visitor);
+	my($btree) = Tree::Binary -> new('*')
+					-> setLeft
+						(
+							Tree::Binary -> new('+')
+								-> setLeft(Tree::Binary->new('2') )
+								-> setRight(Tree::Binary->new('2') )
+						)
+					-> setRight
+						(
+							Tree::Binary->new('+')
+								-> setLeft(Tree::Binary->new('4') )
+								-> setRight(Tree::Binary->new('5') )
+						);
 
-  # print the expression in postfix order
-  print $visitor->getAccumulation(); # prints "2 2 + 4 5 + *"
+	# Or shown visually:
+	#     +---(*)---+
+	#     |         |
+	#  +-(+)-+   +-(+)-+
+	#  |     |   |     |
+	# (2)   (2) (4)   (5)
 
-  # get a Breadth First visitor
-  my $visitor = Tree::Binary::Visitor::BreadthFirstTraversal->new();
-  $btree->accept($visitor);
+	# There is no method which will display the above,
+	# but a crude tree-printer follows.
 
-  # print the expression in breadth first order
-  print $visitor->getAccumulation(); # prints "* + + 2 2 4 5"
+	my($parent_depth);
 
-  # be sure to clean up all circular references
-  $btree->DESTROY();
+	$btree -> traverse
+	(
+		sub
+		{
+			my($tree) = @_;
+
+			print "\t" x $tree -> getDepth, $tree -> getNodeValue, "\n";
+		}
+	);
+
+	# Get a InOrder visitor.
+
+	my($visitor) = Tree::Binary::Visitor::InOrderTraversal -> new;
+
+	$btree -> accept($visitor);
+
+	# Print the expression in infix order.
+
+	print join(' ', $visitor -> getResults), "\n"; # Prints '2 + 2 * 4 + 5'.
+
+	# Get a PreOrder visitor.
+
+	$visitor = Tree::Binary::Visitor::PreOrderTraversal -> new;
+
+	$btree -> accept($visitor);
+
+	# Print the expression in prefix order.
+
+	print join(' ', $visitor -> getResults), "\n"; # Prints '* + 2 2 + 4 5'.
+
+	# Get a PostOrder visitor.
+
+	$visitor = Tree::Binary::Visitor::PostOrderTraversal -> new;
+
+	$btree -> accept($visitor);
+
+	# Print the expression in postfix order.
+
+	print join(' ', $visitor -> getResults), "\n"; # Prints '2 2 + 4 5 + *'.
+
+	# Get a BreadthFirst visitor.
+
+	$visitor = Tree::Binary::Visitor::BreadthFirstTraversal -> new;
+
+	$btree -> accept($visitor);
+
+	# Print the expression in breadth first order.
+
+	print join(' ', $visitor -> getResults), "\n"; # Prints '* + + 2 2 4 5'.
+
+	# Be sure to clean up all circular references.
+	# Of course, since we're exiting immediately, this particular program
+	# does not need such a defensive manoeuvre.
+
+	$btree -> DESTROY();
+
+If printing the tree is important, you are better off using
+L<Tree::DAG_Node|https://metacpan.org/pod/Tree::DAG_Node#tree2string-options-some_tree>.
 
 =head1 DESCRIPTION
 
@@ -479,7 +529,7 @@ This method sets C<$tree> to be the left subtree of the current Tree::Binary obj
 
 =item B<removeLeft>
 
-This method removed the left subtree of the current Tree::Binary object, making sure to remove all references to the current tree. However, in order to properly clean up and circular references the removed child might have, it is advised to call it's C<DESTROY> method. See the L<CIRCULAR REFERENCES> section for more information.
+This method removed the left subtree of the current Tree::Binary object, making sure to remove all references to the current tree. However, in order to properly clean up and circular references the removed child might have, it is advised to call the C<DESTROY> method. See the L<CIRCULAR REFERENCES> section for more information.
 
 =item B<setRight ($tree)>
 
@@ -487,7 +537,7 @@ This method sets C<$tree> to be the right subtree of the current Tree::Binary ob
 
 =item B<removeRight>
 
-This method removed the right subtree of the current Tree::Binary object, making sure to remove all references to the current tree. However, in order to properly clean up and circular references the removed child might have, it is advised to call it's C<DESTROY> method. See the L<CIRCULAR REFERENCES> section for more information.
+This method removed the right subtree of the current Tree::Binary object, making sure to remove all references to the current tree. However, in order to properly clean up and circular references the removed child might have, it is advised to call the C<DESTROY> method. See the L<CIRCULAR REFERENCES> section for more information.
 
 =back
 
@@ -551,10 +601,17 @@ This method will return true (C<1>) if the current Tree::Binary object is the ro
 
 This method takes a single argument of a subroutine reference C<$func>. If the argument is not defined and is not in fact a CODE reference then an exception is thrown. The function is then applied recursively to both subtrees of the invocant. Here is an example of a traversal function that will print out the hierarchy as a tabbed in list.
 
-  $tree->traverse(sub {
-        my ($_tree) = @_;
-        print (("\t" x $_tree->getDepth()), $_tree->getNodeValue(), "\n");
-        });
+This code is taken from scripts/traverse.1.pl:
+
+	$btree -> traverse
+	(
+		sub
+		{
+			my($tree) = @_;
+
+			print "\t" x $tree -> getDepth, $tree -> getNodeValue, "\n";
+		}
+	);
 
 =item B<mirror>
 
@@ -596,7 +653,7 @@ Returns the length of the longest path from the current tree to the furthest lea
 
 =item B<accept ($visitor)>
 
-It accepts either a B<Tree::Binary::Visitor::*> object, or an object who has the C<visit> method available (tested with C<$visitor-E<gt>can('visit')>). If these qualifications are not met, and exception will be thrown. We then run the Visitor's C<visit> method giving the current tree as its argument.
+It accepts either a B<Tree::Binary::Visitor::*> object, or an object who has the C<visit> method available (tested with C<$visitor-E<gt>can('visit')>). If these qualifications are not met, and exception will be thrown. We then run the Visitor C<visit> method giving the current tree as its argument.
 
 =item B<clone>
 
@@ -604,17 +661,17 @@ The clone method does a full deep-copy clone of the object, calling C<clone> rec
 
 =item B<cloneShallow>
 
-This method is an alternate option to the plain C<clone> method. This method allows the cloning of single B<Tree::Binary> object while retaining connections to the rest of the tree/hierarchy. This will attempt to call C<clone> on the invocant's node if the node is an object (and responds to C<$obj-E<gt>can('clone')>) otherwise it will just copy it.
+This method is an alternate option to the plain C<clone> method. This method allows the cloning of single B<Tree::Binary> object while retaining connections to the rest of the tree/hierarchy. This will attempt to call C<clone> on the invocant node if the node is an object (and responds to C<$obj-E<gt>can('clone')>) otherwise it will just copy it.
 
 =item B<DESTROY>
 
-To avoid memory leaks through uncleaned-up circular references, we implement the C<DESTROY> method. This method will attempt to call C<DESTROY> on each of its children (if it as any). This will result in a cascade of calls to C<DESTROY> on down the tree. It also cleans up it's parental relations as well.
+To avoid memory leaks through uncleaned-up circular references, we implement the C<DESTROY> method. This method will attempt to call C<DESTROY> on each of its children (if it as any). This will result in a cascade of calls to C<DESTROY> on down the tree. It also cleans up the parental relations as well.
 
-Because of perl's reference counting scheme and how that interacts with circular references, if you want an object to be properly reaped you should manually call C<DESTROY>. This is especially nessecary if your object has any children. See the section on L<CIRCULAR REFERENCES> for more information.
+Because of perl reference counting scheme and how that interacts with circular references, if you want an object to be properly reaped you should manually call C<DESTROY>. This is especially nessecary if your object has any children. See the section on L<CIRCULAR REFERENCES> for more information.
 
 =item B<fixDepth>
 
-For the most part, Tree::Binary will manage your tree's depth fields for you. But occasionally your tree's depth may get out of place. If you run this method, it will traverse your tree correcting the depth as it goes.
+For the most part, Tree::Binary will manage your tree depth fields for you. But occasionally your tree depth may get out of synch. If you run this method, it will traverse your tree correcting the depth as it goes.
 
 =back
 
@@ -671,7 +728,7 @@ As you can see if the corrected version we used a new variable to capture the re
 
 =head1 OTHER TREE MODULES
 
-As crazy as it might seem, there are no pure (non-search) binary tree implementations on CPAN (at least not that I could find). I found several balanaced trees of one kind or another (see the C<OTHER TREE MODULES> section of the Tree::Binary::Search documentation for that list). The closet thing I could find was the Tree module described below.
+As crazy as it might seem, there are no pure (non-search) binary tree implementations on CPAN (at least not that I could find). I found several balanced trees of one kind or another (see the C<OTHER TREE MODULES> section of the Tree::Binary::Search documentation for that list). The closet thing I could find was the Tree module described below.
 
 =over 4
 
@@ -733,6 +790,8 @@ L<https://github.com/ronsavage/Tree-Binary>
 
 stevan little, E<lt>stevan@iinteractive.comE<gt>
 
+Since V 1.00, Ron Savage E<lt>ron@savage.net.auE<gt> has been the maintainer.
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2004, 2005 by Infinity Interactive, Inc.
