@@ -6,7 +6,7 @@ use warnings;
 
 use Tree::Binary;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 our @ISA = qw(Tree::Binary);
 
@@ -34,7 +34,7 @@ sub new {
 
 sub _init {
 	my ($self, $node_key, $node_value) = @_;
-    (defined($node_key)) || die "Insufficient Arguments : you must provide a node key";    
+    (defined($node_key)) || die "Insufficient Arguments : you must provide a node key";
 	# set the value of the node key
     $self->{_node_key} = $node_key;
     $self->SUPER::_init($node_value);
@@ -43,7 +43,7 @@ sub _init {
 ## ----------------------------------------------------------------------------
 ## accessors
 
-# this value is read-only, to change it 
+# this value is read-only, to change it
 # would compromise the entire data-structure
 sub getNodeKey {
 	my ($self) = @_;
@@ -55,23 +55,23 @@ sub getNodeKey {
 
 sub makeRoot {
     my ($self) = @_;
-    $self->{_parent} = undef;   
+    $self->{_parent} = undef;
     unless ($self->isLeaf()) {
         $self->fixDepth();
     }
     else {
-        $self->{_depth} = 0; 
+        $self->{_depth} = 0;
     }
 }
 
 ## ----------------------------------------------------------------------------
-## cloning 
+## cloning
 
 sub clone {
     my ($self) = @_;
     # first clone the value in the node
-    my $cloned_node = Tree::Binary::_cloneNode($self->getNodeValue());   
-    # create a new Tree::Simple object 
+    my $cloned_node = Tree::Binary::_cloneNode($self->getNodeValue());
+    # create a new Tree::Simple object
     # here with the cloned node, however
     # we do not assign the parent node
     # since it really does not make a lot
@@ -87,8 +87,8 @@ sub clone {
     # the parent of the children to be that of
     # the clone (which is correct)
     $clone->setLeft($self->{_left}->clone()) if $self->hasLeft();
-    $clone->setRight($self->{_right}->clone()) if $self->hasRight();                  
-    # return the clone            
+    $clone->setRight($self->{_right}->clone()) if $self->hasRight();
+    # return the clone
     return $clone;
 }
 
@@ -111,7 +111,7 @@ Tree::Binary::Search::Node - A node for a Tree::Binary::Search tree
 
 =head1 DESCRIPTION
 
-This is a subclass of Tree::Binary and is mostly used by Tree::Binary::Search. 
+This is a subclass of Tree::Binary and is mostly used by Tree::Binary::Search.
 
 =head1 METHODS
 
@@ -131,7 +131,7 @@ This is used by Tree::Binary::Search when it need to re-root a tree due to a del
 
 =item B<clone>
 
-Makes sure that the node key is cloned as well. 
+Makes sure that the node key is cloned as well.
 
 =back
 
@@ -147,12 +147,16 @@ Right now, there is nothing preventing you from using anything you want as a nod
 
 =head1 BUGS
 
-None that I am aware of. Of course, if you find a bug, let me know, and I will be sure to fix it. 
+None that I am aware of. Of course, if you find a bug, let me know, and I will be sure to fix it.
 
 =head1 CODE COVERAGE
 
 See the CODE COVERAGE section of Tree::Binary for details.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/Tree-Binary>
+
 =head1 AUTHOR
 
 stevan little, E<lt>stevan@iinteractive.comE<gt>
@@ -164,7 +168,7 @@ Copyright 2004, 2005 by Infinity Interactive, Inc.
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself.
 
 =cut
 
