@@ -8,7 +8,7 @@ use Scalar::Util qw(blessed);
 
 use Tree::Binary::Visitor::Base;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 our @ISA = qw(Tree::Binary::Visitor::Base);
 
@@ -21,7 +21,7 @@ sub visit {
     my @results;
     # get our filter function
     my $filter_function = $self->getNodeFilter();
-    # now create a queue for 
+    # now create a queue for
     # processing depth first
     my @queue = ($tree);
     # until our queue is empty
@@ -31,14 +31,14 @@ sub visit {
         # enqueue all the current tree's children
         push @queue => $current_tree->getLeft() if $current_tree->hasLeft();
         push @queue => $current_tree->getRight() if $current_tree->hasRight();
-        # now collect the results 
-        push @results => (($filter_function) ? 
+        # now collect the results
+        push @results => (($filter_function) ?
                                     $filter_function->($current_tree)
                                     :
                                     $current_tree->getNodeValue());
-    }        
+    }
     # store our results
-    $self->setResults(@results);    
+    $self->setResults(@results);
 }
 
 
@@ -52,13 +52,15 @@ Tree::Binary::Visitor::BreadthFirstTraversal - Visitor object for Tree::Binary o
 
 =head1 SYNOPSIS
 
+For a complete example, see also L<Tree::Binary/SYNOPSIS>.
+
   use Tree::Binary;
   use Tree::Binary::Visitor::BreadthFirstTraversal;
-  
+
   # create a visitor instance
-  my $visitor = Tree::Binary::Visitor::BreadthFirstTraversal->new();  							 
-  
-  # create a tree to visit 
+  my $visitor = Tree::Binary::Visitor::BreadthFirstTraversal->new();
+
+  # create a tree to visit
   # this is an expression tree
   # representing ((2 + 2) * (4 + 5))
   my $btree = Tree::Binary->new("*")
@@ -69,21 +71,21 @@ Tree::Binary::Visitor::BreadthFirstTraversal - Visitor object for Tree::Binary o
                                 ->setLeft(Tree::Binary->new("4"))
                                 ->setRight(Tree::Binary->new("5")));
 
-  # by default this will collect all the 
-  # node values in depth-first order into 
-  # our results 
-  $tree->accept($visitor);	  
-  
+  # by default this will collect all the
+  # node values in depth-first order into
+  # our results
+  $tree->accept($visitor);
+
   # get our results and print them
-  print join ", ", $visitor->getResults();  # prints "*, +, +, 2, 2, 4, 5" 
-  
-  # for more complex node objects, you can specify 
+  print join ", ", $visitor->getResults();  # prints "*, +, +, 2, 2, 4, 5"
+
+  # for more complex node objects, you can specify
   # a node filter which will be used to extract the
   # information desired from each node
-  $visitor->setNodeFilter(sub { 
+  $visitor->setNodeFilter(sub {
                 my ($t) = @_;
                 return $t->getNodeValue()->description();
-                });  
+                });
 
 =head1 DESCRIPTION
 
@@ -125,12 +127,16 @@ The C<visit> method accepts a Tree::Binary and applies the function set in C<new
 
 =head1 BUGS
 
-None that I am aware of. Of course, if you find a bug, let me know, and I will be sure to fix it. 
+None that I am aware of. Of course, if you find a bug, let me know, and I will be sure to fix it.
 
 =head1 CODE COVERAGE
 
 See the CODE COVERAGE section of Tree::Binary for details.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/Tree-Binary>
+
 =head1 AUTHOR
 
 stevan little, E<lt>stevan@iinteractive.comE<gt>
@@ -142,6 +148,6 @@ Copyright 2004, 2005 by Infinity Interactive, Inc.
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself.
 
 =cut
\ No newline at end of file
