@@ -4,9 +4,9 @@ package Tree::Binary::VisitorFactory;
 use strict;
 use warnings;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
-sub new { 
+sub new {
     my ($class) = @_;
     return bless \$class;
 }
@@ -33,19 +33,20 @@ Tree::Binary::VisitorFactory - A factory object for dispensing Visitor objects
 =head1 SYNOPSIS
 
   use Tree::Binary::VisitorFactory;
-  
+
   my $tf = Tree::Binary::VisitorFactory->new();
-  
-  my $visitor = $tf->get("InOrderTraveral");
-  
-  # or call it as a class method
-  my $visitor = Tree::Binary::VisitorFactory->getVisitor("PostOrderTraveral");
+
+  my $visitor = $tf->get('InOrderTraveral');
+
+  # Or call it as a class method:
+
+  my $visitor = Tree::Binary::VisitorFactory->getVisitor('PostOrderTraveral');
 
 =head1 DESCRIPTION
 
-This object is really just a factory for dispensing Tree::Binary::Visitor::* objects. It is not required to use this package in order to use all the Visitors, it is just a somewhat convienient way to avoid having to type thier long class names. 
+This object is really just a factory for dispensing Tree::Binary::Visitor::* objects. It is not required to use this package in order to use all the Visitors, it is just a somewhat convienient way to avoid having to type thier long class names.
 
-I considered making this a Singleton, but I did not because I thought that some people might not want that. I know that I am very picky about using Singletons, especially in multiprocess environments like mod_perl, so I implemented the smallest instance I knew how to, and made sure all other methods could be called as class methods too. 
+I considered making this a Singleton, but I did not because I thought that some people might not want that. I know that I am very picky about using Singletons, especially in multiprocess environments like mod_perl, so I implemented the smallest instance I knew how to, and made sure all other methods could be called as class methods too.
 
 =head1 METHODS
 
@@ -67,12 +68,16 @@ This is an alias of C<get>.
 
 =head1 BUGS
 
-None that I am aware of. Of course, if you find a bug, let me know, and I will be sure to fix it. 
+None that I am aware of. Of course, if you find a bug, let me know, and I will be sure to fix it.
 
 =head1 CODE COVERAGE
 
 See the CODE COVERAGE section of Tree::Binary for details.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/Tree-Binary>
+
 =head1 AUTHOR
 
 stevan little, E<lt>stevan@iinteractive.comE<gt>
@@ -84,7 +89,7 @@ Copyright 2004, 2005 by Infinity Interactive, Inc.
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself.
 
 =cut
 
